%% ===================================================
%% its06workshop Workshop Class.
%% Collin Lynch.
%% 03/24/2006
%%
%% Copyright 2006 Collin Lynch.
%% This class is distributed under the terms of the 
%% GNU Public License version 2.  Text is available
%% in this directory as gpl.txt
%%
%% This class file provides for the its06workshop class.
%% It will do all of the necessary documernt layout to 
%% ensure that the submission conforms with the its06 
%% workshop template provided by the workshop chairs.
%%
%% The contents of this file have been based upon the 
%% standard latex article class provided by the latex 
%% authors.
%%
%% It has also been based (with permission) on the ACM 
%% Special proceedings file format written by Leslie 
%% Lamport.  That format may be obtained online.  
%%
%% Use of this file is specified by the sample.tex file
%% or the associated sample.pdf file.  
%%
%% This class also makes use of the vmargin package by
%% Volker Kuhlmann.  A copy of that package has been 
%% included here.  Consult the package files for 
%% copyright info.
%%
%% It also makes use of the apalike bibtex style by 
%% Oren Patashnik.  Consult the file itself for copyright
%% info.  
%%
%% In the sections below the relevant commands are laid 
%% out as needed.  Simply read them to get a better 
%% understanding of the class's use.  
%% =====================================================

%% ------------------------------------------------------
%% The Standard ProvidesClass command that specifys the 
%% name used with this file.  
\ProvidesClass{its06workshop}

%% ------------------------------------------------------
%% For the purposes of this most of the ``grunt work'' is 
%% handled by the existing article class.  For that reason
%% I am passing most of the options through to it by loading
%% it initially.  
\LoadClass{article}

%% -----------------------------------------------------
%% The VMargin package provides useful commands for
%% Altering page sizes.
\usepackage{vmargin}



%% -------------------------------------------------------
%% Page Sizes and spacing.
%%
%% Original Comment
%% PAGE SIZE
%%
%%
%% All material on each page should be centered on an A4 
%% (8.26 x 11.69 inch) page with 2.5cm (or 1 inch) 
%% margins all around. It is important to check 
%% these margins even if you use this Word template, 
%% because they might have been overwritten by your local 
%% settings.
%%
%%
%% Page Numbering, Headers and Footers
%% Do NOT include headers, footers or page numbers in your submission. 
%% These will be added when the publications are assembled.
%% 
%% This is handled by eliminating headers and footers.
%% --------------------------------------------------------

%% By default the paper size is set to A4 although this may be 
%% Changed by the options below.
\setpapersize[portrait]{A4}


%% Paper sizing is contolled by options.  In this case the a4
%% Paper Size is set.
\DeclareOption{a4paper}{\setpapersize[portrait]{A4}}
%% Alternately set the letter paper size.
\DeclareOption{letterpaper}{\setpapersize[portrait]{USLetter}}


%% Set the Margins themselves.  The Text width will be calculated
%% automatically from the margins supplied.  The initial commented 
%% command allows one to set the margins including head height 
%% and footer height.  
%
%% Note the command below that is actually used where these arguments
%%  have been eliminated.  They will be setto zero by that command
%%  thus rendering the effect of the ``empty'' pagestyle.  
%
%% This provides no headers or footers. 
%\newcommand{\SetDefaultMargins}{
%%  \setmarginsrb
%%      {1in}  %% Left Margin.
%%      {1in}  %% Top Margin.
%%      {1in}  %% Right Margin.
%%      {1in}  %% Bottom Margin.
%%      {0in}  %% Head Height.
%%      {0in}  %% Head Separator.
%%      {0in}  %% Footer Height.
%%      {0in}  %% Footer Separator.   
%%    }

\newcommand{\SetDefaultMargins}{
  \setmargnohfrb
      {1in}  %% Left Margin.
      {1in}  %% Top Margin.
      {1in}  %% Right Margin.
      {1in}  %% Bottom Margin.
    }

\SetDefaultMargins




%% ---------------------------------------------------------------
%% FORMATTED TEXT
%% Carefully format your submission using the following styles:
%% Title and Authors
%% The title (Helvetica 18-point bold), authors' names (Times New 
%% Roman 12-point bold) and affiliations (Times New Roman 12-point 
%% not-bold) run across the full width of the page. We also recommend 
%% that you add your e-mail address using the affiliations style. 
%%
%% Abstract and Keywords
%% Place two blank Normal (10 pt.) lines after the title, followed by 
%% an abstract of about 100 words. The abstract should begin with the 
%% word "Abstract." in bold, and should be formatted in the "Abstract" 
%% style provided in this template (like Normal, but indented 1cm each 
%% side). The abstract should be a concise statement of the problem, 
%% approach, findings, and conclusions of the work described.
%%
%% Place one blank Normal line after the abstract, followed by the word 
%% "Keywords." in bold, followed by a set of keywords, this being also 
%% formatted in Abstract style. The keywords should be chosen to be 
%% suitable for both an index of the proceedings and for electronic search.
%%
%% One Normal line should follow the keywords before the first section 
%% header of your paper. 
%% 
%% ---------------------------------------------------------------

%% Define the fonts for the Title elements.
%% These commands will be called below to set the font sizes as needed.

%% The titles are 18 point bold helvetica (phv).
\newcommand{\SetTitleFont}{
  \fontfamily{phv}
  \fontseries{b}
  \fontshape{n}
  \fontsize{18pt}{23pt} % Set the font size to 18 with 23 pt spacing btw lines.
  \selectfont
}

%% The Authors names are 12 pt bold text Times New Roman.
\newcommand{\SetAuthNameFont}{
  \fontfamily{ptm}
  \fontseries{b}
  \fontshape{n}
  \fontsize{12pt}{15pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}

%% The Authors affiliations are 12 pt text Times New Roman.
\newcommand{\SetAuthAffilFont}{
  \fontfamily{ptm}
  \fontseries{m}
  \fontshape{n}
  \fontsize{12pt}{15pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}

%% The Authors e-mails are 12 pt italic text Times New Roman.
\newcommand{\SetAuthEmailFont}{
  \fontfamily{ptm}
  \fontseries{m}
  \fontshape{it}
  \fontsize{12pt}{15pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}


%% Additional Authors should be specified using 
%% Body size text as is done here.

%% The Authors names are 12 pt bold text Times New Roman.
\newcommand{\SetAddAuthNameFont}{
  \fontfamily{ptm}
  \fontseries{b}
  \fontshape{n}
  \fontsize{10pt}{12pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}

%% The Authors affiliations are 12 pt text Times New Roman.
\newcommand{\SetAddAuthAffilFont}{
  \fontfamily{ptm}
  \fontseries{m}
  \fontshape{n}
  \fontsize{10pt}{12pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}

%% The Authors e-mails are 12 pt italic text Times New Roman.
\newcommand{\SetAddAuthEmailFont}{
  \fontfamily{ptm}
  \fontseries{m}
  \fontshape{it}
  \fontsize{10pt}{12pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}






%% The Following code was liberally liberated from the acm sig-alternate
%% class that was referenced in the header.  It has been modified to 
%% fit the present needs.  
\newcount\aucount
\newcount\originalaucount
\newdimen\auwidth
\auwidth=\textwidth
\newdimen\auskip
\newcount\auskipcount
\newdimen\auskip
\global\auskip=1pc
\newdimen\allauboxes
\allauboxes=\auwidth
\newtoks\addauthors
\newcount\addauflag
\global\addauflag=0 %Haven't shown additional authors yet

\newtoks\subtitletext
\gdef\subtitle#1{\subtitletext={#1}}

\gdef\additionalauthors#1{\addauthors={#1}}

%% This command also modified from the sig-alternate.cls handles spacing
%% issues for the author layout.  
\gdef\numberofauthors#1{\global\aucount=#1
  \ifnum\aucount>4\global\originalaucount=\aucount \global\aucount=4\fi %g}
  \global\auskipcount=\aucount\global\advance\auskipcount by 1
  %
  % Make the spacing dyamic to the authors themselves.
  \global\multiply\auskipcount by 1
  %\ifnum\aucount=2\global\multiply\auskipcount by 1\fi
  %\ifnum\aucount=3\global\multiply\auskipcount by 1\fi
  %\ifnum\aucount=4\global\multiply\auskipcount by 1\fi
  %
  \global\multiply\auskip by \auskipcount
  \global\advance\auwidth by -\auskip
  \global\divide\auwidth by \aucount}

%% This command was modified from the sig-alternate style and handles
%% basic spacing issues for the authors.  it is employed by itsauth.
\def\alignauthor{%                 
  \end{tabular}%
  \begin{tabular}[t]{p{\auwidth}}\centering}%


%% Basic layout for the head author list.  It includes 
%% layouts for the main titles.  Additional authors are
%% laid out by the code below.
\newcommand{\headauth}[3]{
  \SetAuthNameFont #1
  \SetAuthAffilFont #2
  \SetAuthEmailFont #3
  }


%% Defines the Firstauth and mainauth commands as needed.
\newcommand{\firstauth}[3]{\headauth{#1\\}{#2\\}{#3}}
\newcommand{\mainauth}[3]{
  \alignauthor
  \headauth{#1\\}{#2\\}{#3}}
\newcommand{\mainauthEf}[3]{
  \alignauthor
  \headauth{#1\\}{#2\footnote{#3}}{}}


%% Additional Authors are specified in an additional section
%% that will be used to list them separately.  This code was
%% copied from the sig class.
\def\addauthorsection{\ifnum\originalaucount>4
  \section{Additional Authors}
  \begin{description}
    \the\addauthors
  \end{description}
  \fi}

%% Text formatting for the additional authors is done using the
%% body text font but with bold, normal, and italics as appropriate.
%% additional authors should be layed out using the \addauth command.
\newcommand{\addauth}[3]{
  \item[{\SetAddAuthNameFont #1}]
    {\SetAddAuthAffilFont #2} {\SetAddAuthEmailFont #3}
}

%% This is another internal command taken from the article class.
%% it was copied soley to ensure that the page style was not set
%% to plain as is done by the article class.  The commented line with 
%% a note shows the location of this change.  
\renewcommand\maketitle{\par
  \begingroup
    \renewcommand\thefootnote{\@fnsymbol\c@footnote}%
    \def\@makefnmark{\rlap{\@textsuperscript{\normalfont\@thefnmark}}}%
    \long\def\@makefntext##1{\parindent 1em\noindent
            \hb@xt@1.8em{%
                \hss\@textsuperscript{\normalfont\@thefnmark}}##1}%
    \if@twocolumn
      \ifnum \col@number=\@ne
        \@maketitle
      \else
        \twocolumn[\@maketitle]%
      \fi
    \else
      \newpage
      \global\@topnum\z@   % Prevents figures from going at top of page.
      \@maketitle
    \fi
    %\thispagestyle{plain}\@thanks   %  Commented to ensure empty page style.
  \endgroup
  \setcounter{footnote}{0}%
  \global\let\thanks\relax
  \global\let\maketitle\relax
  \global\let\@maketitle\relax
  \global\let\@thanks\@empty
  \global\let\@author\@empty
  \global\let\@date\@empty
  \global\let\@title\@empty
  \global\let\title\relax
  \global\let\author\relax
  \global\let\date\relax
  \global\let\and\relax
}


%% This is an internal command used by the \maketitle command.
%% this code has been modified from the core Article.cls class
%% defined by the tex distribution.  It should be employed
%% properly by the command \maketitle employed by the user.
%% note that it does not print the date.
\def\@maketitle{%
  \null
  \begin{center}%                
    %
    \let \footnote \thanks       % Ensure that footnotes are handled.
    %
    {\SetTitleFont               % Set title Font.
       \@title \par}%            % Print the title. 
    %
    \vskip 1.5em%
    %
    {\begin{tabular}[t]{p{\auwidth}} % Align the titles as needed.
	\centering                   % Set centering for the paragraph.
        \@author                     % Insert the contents of \@author
      \end{tabular}}%                 % End the tabular environent.
  %
  \end{center}%
  %
  \vskip 20pt                     % Skip 20pt before the Abstract.
}



%% A new inner environment used for the abstract and te keywords.
%% it does the necessary indentations.  
\newenvironment
    {itsinnerenviron}
    { \SetBodyTextFont             % Use the standard body font.  
      \list{}{\rightmargin 1cm     % Start a custom list environment
	\leftmargin 1cm}           % with margins of 1cm on each side.
      \item\relax}                   % Start an item w. no char
    { \endlist }                   % end the list environment.


%% Renew the abstract environment with a spacing after it to make clear
%% areas.  This includes adding padding around it itself.  
\renewenvironment
    {abstract}
    {\begin{itsinnerenviron}
     \textbf{Abstract:}}
    {\end{itsinnerenviron}}

      

%% The Keywords Environment lays out the keywords in the same
%% essential form as the abstract.
\newenvironment
    {keywords}
    {\begin{itsinnerenviron}
     \textbf{Keywords:}}
    {\end{itsinnerenviron}}




%% -----------------------------------------------------------------------
%% Body Text
%% Format the first paragraph of each section (following the section title) 
%% in the style "Body Text," like this paragraph. Please use a 10-point 
%% Times New Roman font, or other Roman font with serifs, as close as 
%% possible in appearance to Times New Roman in which these guidelines have 
%% been set. The goal is to have a 10-point text, as you see here. Please 
%% use sans-serif or non-proportional fonts only for special purposes, such 
%% as distinguishing source code text (use 9 point Courier or similar). The 
%% Press 10-point font available to users of Script is a good substitute 
%% for Times New Roman. If Times New Roman is not available, try Times or 
%% Computer Modern Roman.
%%
%% Format all remaining paragraphs of your paper in the style "Body Text 
%% First Indent," like this paragraph. This style is like Body Text, but 
%% the first line is indented 0.5cm. 
%% ----------------------------------------------------------------------

%% For the purposes of this all that should be necessary is to set the text
%% as the standard format and leave it at that.  
\newcommand{\SetBodyTextFont}{
  \fontfamily{ptm}
  \fontseries{m}
  \fontshape{n}
  \fontsize{10pt}{12pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont}

\SetBodyTextFont


%% Set paragraph indenting for future paragraphs.
\setlength{\parindent}{0.5cm}



%% -------------------------------------------------------------------
%% Lists 
%% See example of List Bullet here: 
%% For lists, bulleted lists, and numbered lists, please use the MS Word 
%% styles "List," "List 2," "List Bullet," "List Bullet 2," "List Number," 
%% "List Number 2," etc.
%% This is an example of lists.
%%
%% For the purposes of this document I am going (for now) with the 
%% default values of the itemize, enumerate, and description.
%% -----------------------------------------------------------------------



%% ---------------------------------------------------------------------
%% References and Citations
%% Use the standard APA (American Psychological Association) format for 
%% references - that is, a list at the end of the article, ordered 
%% alphabetically by first author, and referenced by publication year in 
%% parentheses. Be consistent with capitalization. See the examples of 
%% references at the end of this document. Within this template file, use 
%% the style named "References" for the text of your references (hanging 
%% paragraphs indented by 1 cm, with no space between lines). Within your 
%% text, cite the references with (Author, year).
%%
%% References should be published materials accessible to the public. 
%% Internal technical reports may be cited only if they are easily 
%% accessible (i.e., you give an Internet address within your citation). 
%% Proprietary information may not be cited. Private communications should 
%% be acknowledged, not referenced, e.g., "(Robertson, personal 
%% communication)."
%%
%% REFERENCES
%% Mackay, W. E. (1995) Ethics, lies and videotape. Proceedings of 
%% CHI '95 (Denver, CO, May 1995), ACM Press, 138-145.
%%
%% Paulson, F. L., Paulson, P. R. and Meyer, C. A. (1991) What makes a 
%% portfolio a portfolio?. Educational Leadership, 48, 5, 60-63.
%%
%% Pope, M. L. and Keen, T. R. (1981) Personal Construct Psychology 
%% and Education. Academic Press, London.
%%
%% In order to satisfy this the apalike reference is used.
%% -------------------------------------------------------------
\bibliographystyle{apalike}

%% The definition code below was taken from the Article class.
%% It differs only by the alteration of \section* to \section 
\renewcommand\refname{References}
\renewenvironment{thebibliography}[1] 
     {\ifnum\addauflag=0\addauthorsection\global\addauflag=1\fi
      \section{\refname}%               % formerly \section*{\refname}
      \@mkboth{\MakeUppercase\refname}{\MakeUppercase\refname}%
      \list{\@biblabel{\@arabic\c@enumiv}}%
           {\settowidth\labelwidth{\@biblabel{#1}}%
            \leftmargin\labelwidth
            \advance\leftmargin\labelsep
            \@openbib@code
            \usecounter{enumiv}%
            \let\p@enumiv\@empty
            \renewcommand\theenumiv{\@arabic\c@enumiv}}%
      \sloppy
      \clubpenalty4000
      \@clubpenalty \clubpenalty
      \widowpenalty4000%
      \sfcode`\.\@m}
     {\def\@noitemerr
       {\@latex@warning{Empty `thebibliography' environment}}%
      \endlist}


%% -----------------------------------------------------------------------
%% SECTIONS
%% The heading of a section should be in Helvetica 12-point bold in 
%% all-capitals. Sections should NOT be numbered. Provide 12 points space 
%% before the heading and 6 space points after. 
%%
%% Subsections
%% The heading of subsections should be in Helvetica 10-point bold with 
%% only the initial letters capitalized. Provide 12 points space before 
%% and 6 points after the heading.
%%
%% Sub-subsections
%% The heading for sub-subsections should be in Helvetica 10-point italic 
%% with initial letters capitalized. Provide 6 points space before the 
%% heading and no space after. 
%% -----------------------------------------------------------------------

%% Set the appropriate header font for the section.
\newcommand{\SetSectionHeadFont}{
  \fontfamily{phv} % Helvetica.
  \fontseries{b}  % Bold Medium width.
  \fontshape{n}    % Normal upright.
  \fontsize{12pt}{15pt} % Set the font size to 12 with 15 pt spacing btw lines.
  \selectfont
}

%% Renew the section command with the appropriate settings.
\renewcommand{\section}{
  \stepcounter{section}
  \@afterindentfalse
  \@startsection {section} % Name of the section.
		 {1}       % Level of the section in the section heirarchy.
		 {0cm}     % Amount of indent before the section.
		 {-12pt}   % Space before section heading to skip.
                          % Negation ensures that the first par isn't indented.
		 {6pt}     % Space after section heading to skip.
		 {\SetSectionHeadFont\MakeUppercase}* 
                           % Set the font for the heading.
}


\newcommand{\SetSubSectionHeadFont}{
  \fontfamily{phv}  % Helvetica.
  \fontseries{b}   % Bold Medium width.
  \fontshape{n}     % Normal upright.
  \fontsize{10pt}{12pt}  % 10 pt font w 12pt line size.
  \selectfont
}

%% Renew the section command with the appropriate settings.
\renewcommand{\subsection}{
  \@startsection
      {subsection} % Name of the section.
      {2}       % Level of the section in the section heirarchy.
      {0cm}     % Amount of indent before the section.
      {-12pt}   % Space before section heading to skip.
                % Negation ensures that the first par isn't indented    
      {6pt}     % Space after section heading to skip.
      {\SetSubSectionHeadFont}  % Set the font for the heading.
}

\newcommand{\SetSubSubSectionHeadFont}{
  \fontfamily{phv} % Helvetica
  \fontseries{m}  % Medium Medium width.
  \fontshape{it}   % Italicized.
  \fontsize{10pt}{12pt} % 10pt 12pt skip.
  \selectfont
}

%% Renew the section command with the appropriate settings.
\renewcommand{\subsubsection}{
  \@startsection
      {subsubsection} % Name of the section.
      {3}       % Level of the section in the section heirarchy.
      {0cm}     % Amount of indent before the section.
      {-6pt}    % Space before section heading to skip.
                % Negation ensures that the first par isn't indented    
      {0.01pt}     % Space after section heading to skip.
      {\SetSubSubSectionHeadFont}  % Set the font for the heading.
}


%% -----------------------------------------------------------------------
%% FIGURES and TAbles
%% Figures and tables should be inserted at the appropriate point in your 
%% text. Each figure and table should have a figure caption in Normal 
%% Times New Roman 10 point font.
%%
%% Handling this is a bit of a pain in the ass in that the captions are
%% listed in the spacing using a tex command.  The code below is based
%% Strongly upon the tex command in this comment that was itself taken from
%% the basic article.cls class.
%%
%% \long\def\@makecaption#1#2{%
%%   \vskip\abovecaptionskip
%%   \sbox\@tempboxa{#1: #2}%
%%   \ifdim \wd\@tempboxa >\hsize
%%     #1: #2\par
%%   \else
%%     \global \@minipagefalse
%%     \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
%%   \fi
%%   \vskip\belowcaptionskip}
%% -----------------------------------------------------------------------

%% Setthe aption for the font.
\newcommand{\SetCaptionFont}{
  \fontfamily{ptm}  % Helvetica.
  \fontseries{m}   % Bold Medium width.
  \fontshape{n}     % Normal upright.
  \fontsize{10pt}{12pt}  % 10 pt font w 12pt line size.
  \selectfont
}


%% As a hack forceably replace the \@makecaption command from
%% article.cls which is itself replaced from who knows where.
%% this one only differs by the addition of the \SetCaptionFont
%% command.  In the future this should be done in a cleaner way.
\long\def\@makecaption#1#2{%
  \vskip\abovecaptionskip
  \sbox\@tempboxa{\SetCaptionFont#1: #2}%
  \ifdim \wd\@tempboxa >\hsize
    #1: #2\par
  \else
    \global \@minipagefalse
    \hb@xt@\hsize{\hfil\box\@tempboxa\hfil}%
  \fi
  \vskip\belowcaptionskip}